********
pywrapid
********

This collection of libraries is created to extend popular libraries functionalities for rapid development of python applications (lower time to market).
Includes configuration management compatible with all other modules provided in pywrapid, but also allows stand alone usage.

Extend functionality as you wish by wrapping the modules and/or inheriting the classes.


.. toctree::

    user-guide
    developer-guide
    features
